pub struct CompoundSelector {
pub parts: Vec<SimpleSelector>,
}Expand description
A compound selector: one or more simple selectors applied to a single node.
E.g., div.active#main[data-x] is a single compound with 4 parts.
Fields
parts: Vec<SimpleSelector>Simple selectors that must all match the same node.